==> audit-1.2.1.tgz: package/lib/audit/index.js <==
/* eslint class-methods-use-this: 0 */

const _ = require('lodash');
const auditDal = require('./audit.dal');
const queryBuilder = require('./audit.query');

class Audit {
    store(auditData) {
        const audit = {
            accountId: _.get(auditData, 'metainfo.accountId'),
            userId: _.get(auditData, 'metainfo.userId'),
            userName: _.get(auditData, 'metainfo.userName'),
            userEmail: _.get(auditData, 'metainfo.userEmail'),
            req_body: JSON.stringify(_.get(auditData, 'request.body')),
            req_query: JSON.stringify(_.get(auditData, 'request.query')),
            req_params: JSON.stringify(_.get(auditData, 'request.params')),
            req_headers: JSON.stringify(_.get(auditData, 'request.headers')),
            res_body: JSON.stringify(_.get(auditData, 'response.body')),
            entity: _.get(auditData, 'metainfo.entity'),
            entityId: _.get(auditData, 'metainfo.entityId'),
            entityName: _.get(auditData, 'metainfo.entityName'),
            action: _.get(auditData, 'metainfo.action'),
            req_url: _.get(auditData, 'request.url'),
            rs_status: _.get(auditData, 'response.status'),
            createdAt: new Date(),
            correlationId: _.get(auditData, 'metainfo.correlationId'),
            ip: _.get(auditData, 'metainfo.ip'),
            loggedInByAdmin: _.get(auditData, 'metainfo.loggedInByAdmin'),
        };
        return auditDal.store(audit);
    }

    init(needCreateDb = false) {
        return auditDal.init(needCreateDb);
    }

    getAudit({ accountId, qs }) {
        return auditDal.getAudit(queryBuilder.buildQuery(qs, accountId));
    }

    getUserNames(accountId) {
        return auditDal.getUserNames(accountId);
    }

    async getEntitiesList(accountId, opts) {
        const list = await auditDal.getEntitiesList(accountId, opts);

        return _.reduce(list, (result, raw) => {
            (result[raw.entity] || (result[raw.entity] = [])).push(raw.action);
            return result;
        }, {});
    }

}

module.exports = new Audit();

==> audit-1.2.2.tgz: package/lib/audit/index.js <==
/* eslint class-methods-use-this: 0 */

const _ = require('lodash');
const auditDal = require('./audit.dal');
const queryBuilder = require('./audit.query');

class Audit {
    store(auditData) {
        const audit = {
            accountId: _.get(auditData, 'metainfo.accountId'),
            userId: _.get(auditData, 'metainfo.userId'),
            userName: _.get(auditData, 'metainfo.userName'),
            userEmail: _.get(auditData, 'metainfo.userEmail'),
            req_body: JSON.stringify(_.get(auditData, 'request.body')),
            req_query: JSON.stringify(_.get(auditData, 'request.query')),
            req_params: JSON.stringify(_.get(auditData, 'request.params')),
            req_headers: JSON.stringify(_.get(auditData, 'request.headers')),
            res_body: JSON.stringify(_.get(auditData, 'response.body')),
            entity: _.get(auditData, 'metainfo.entity'),
            entityId: _.get(auditData, 'metainfo.entityId'),
            entityName: _.get(auditData, 'metainfo.entityName'),
            action: _.get(auditData, 'metainfo.action'),
            req_url: _.get(auditData, 'request.url'),
            rs_status: _.get(auditData, 'response.status'),
            createdAt: new Date(),
            correlationId: _.get(auditData, 'metainfo.correlationId'),
            ip: _.get(auditData, 'metainfo.ip'),
            loggedInByAdminId: _.get(auditData, 'metainfo.loggedInByAdminId'),
            loggedInByAdminName: _.get(auditData, 'metainfo.loggedInByAdminName'),
        };
        return auditDal.store(audit);
    }

    init(needCreateDb = false) {
        return auditDal.init(needCreateDb);
    }

    getAudit({ accountId, qs }) {
        return auditDal.getAudit(queryBuilder.buildQuery(qs, accountId));
    }

    getUserNames(accountId) {
        return auditDal.getUserNames(accountId);
    }

    async getEntitiesList(accountId, opts) {
        const list = await auditDal.getEntitiesList(accountId, opts);

        return _.reduce(list, (result, raw) => {
            (result[raw.entity] || (result[raw.entity] = [])).push(raw.action);
            return result;
        }, {});
    }

}

module.exports = new Audit();
